BBlack has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/137919

Change subject: zerofetch: action name s/zeroconfig/zeroportal/ (per Yuri)
......................................................................

zerofetch: action name s/zeroconfig/zeroportal/ (per Yuri)

Change-Id: I16606698e8aa3b0c99b226ea560561a9a0d1f654
---
M files/zerofetch.py
1 file changed, 2 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/operations/puppet/varnish 
refs/changes/19/137919/1

diff --git a/files/zerofetch.py b/files/zerofetch.py
index 2c5c554..8053b97 100755
--- a/files/zerofetch.py
+++ b/files/zerofetch.py
@@ -69,9 +69,9 @@
     def __del__(self):
         self.logout
 
     # Fetches zeroconfig of type "ztype" as JSON data
     def zeroconf(self, ztype):
-        return self._apiJSON('get', 'zeroconfig', {'type': ztype})
+        return self._apiJSON('get', 'zeroportal', {'type': ztype})
 
 
 # For use with argparse to validate the output dir exists and is a directory
@@ -69,9 +69,9 @@
         self.logout
 
-    # Fetches zeroconfig of type "ztype" as JSON data
+    # Fetches zeroportal data of type "ztype" as JSON data
     def zeroconf(self, ztype):

-- 
To view, visit https://gerrit.wikimedia.org/r/137919
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I16606698e8aa3b0c99b226ea560561a9a0d1f654
Gerrit-PatchSet: 1
Gerrit-Project: operations/puppet/varnish
Gerrit-Branch: master
Gerrit-Owner: BBlack <bbl...@wikimedia.org>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to